==> kubernetes-model-apiextensions-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceColumnDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CustomResourceColumnDefinitionFluent<A extends CustomResourceColumnDefinitionFluent<A>> extends BaseFluent<A>{
  public CustomResourceColumnDefinitionFluent() {
  }
  
  public CustomResourceColumnDefinitionFluent(CustomResourceColumnDefinition instance) {
    this.copyInstance(instance);
  }
  private String description;
  private String format;
  private String jsonPath;
  private String name;
  private Integer priority;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CustomResourceColumnDefinition instance) {
    instance = (instance != null ? instance : new CustomResourceColumnDefinition());
  
    if (instance != null) {
        this.withDescription(instance.getDescription());
        this.withFormat(instance.getFormat());
        this.withJsonPath(instance.getJsonPath());
        this.withName(instance.getName());
        this.withPriority(instance.getPriority());
        this.withType(instance.getType());
        this.withDescription(instance.getDescription());
        this.withFormat(instance.getFormat());
        this.withJsonPath(instance.getJsonPath());
        this.withName(instance.getName());
        this.withPriority(instance.getPriority());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public String getFormat() {
    return this.format;
  }
  
  public A withFormat(String format) {
    this.format=format; return (A) this;
  }
  
  public boolean hasFormat() {
    return this.format != null;
  }
  
  public String getJsonPath() {
    return this.jsonPath;
  }
  
  public A withJsonPath(String jsonPath) {
    this.jsonPath=jsonPath; return (A) this;
  }
  
  public boolean hasJsonPath() {
    return this.jsonPath != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getPriority() {
    return this.priority;
  }
  
  public A withPriority(Integer priority) {
    this.priority=priority; return (A) this;
  }
  
  public boolean hasPriority() {
    return this.priority != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceColumnDefinitionFluent that = (CustomResourceColumnDefinitionFluent) o;
    if (!java.util.Objects.equals(description, that.description)) return false;
  
    if (!java.util.Objects.equals(format, that.format)) return false;
  
    if (!java.util.Objects.equals(jsonPath, that.jsonPath)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(priority, that.priority)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(description,  format,  jsonPath,  name,  priority,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (format != null) { sb.append("format:"); sb.append(format + ","); }
    if (jsonPath != null) { sb.append("jsonPath:"); sb.append(jsonPath + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-apiextensions-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceColumnDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CustomResourceColumnDefinitionFluent<A extends CustomResourceColumnDefinitionFluent<A>> extends BaseFluent<A>{
  public CustomResourceColumnDefinitionFluent() {
  }
  
  public CustomResourceColumnDefinitionFluent(CustomResourceColumnDefinition instance) {
    this.copyInstance(instance);
  }
  private String description;
  private String format;
  private String jsonPath;
  private String name;
  private Integer priority;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CustomResourceColumnDefinition instance) {
    instance = (instance != null ? instance : new CustomResourceColumnDefinition());
    if (instance != null) {
          this.withDescription(instance.getDescription());
          this.withFormat(instance.getFormat());
          this.withJsonPath(instance.getJsonPath());
          this.withName(instance.getName());
          this.withPriority(instance.getPriority());
          this.withType(instance.getType());
          this.withDescription(instance.getDescription());
          this.withFormat(instance.getFormat());
          this.withJsonPath(instance.getJsonPath());
          this.withName(instance.getName());
          this.withPriority(instance.getPriority());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description = description;
    return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public String getFormat() {
    return this.format;
  }
  
  public A withFormat(String format) {
    this.format = format;
    return (A) this;
  }
  
  public boolean hasFormat() {
    return this.format != null;
  }
  
  public String getJsonPath() {
    return this.jsonPath;
  }
  
  public A withJsonPath(String jsonPath) {
    this.jsonPath = jsonPath;
    return (A) this;
  }
  
  public boolean hasJsonPath() {
    return this.jsonPath != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getPriority() {
    return this.priority;
  }
  
  public A withPriority(Integer priority) {
    this.priority = priority;
    return (A) this;
  }
  
  public boolean hasPriority() {
    return this.priority != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceColumnDefinitionFluent that = (CustomResourceColumnDefinitionFluent) o;
    if (!java.util.Objects.equals(description, that.description)) return false;
    if (!java.util.Objects.equals(format, that.format)) return false;
    if (!java.util.Objects.equals(jsonPath, that.jsonPath)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(priority, that.priority)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(description,  format,  jsonPath,  name,  priority,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (format != null) { sb.append("format:"); sb.append(format + ","); }
    if (jsonPath != null) { sb.append("jsonPath:"); sb.append(jsonPath + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
